import request from '@/utils/request'

// 初始化项目
export function initProject() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_项目名称_查询数据_按时间排序'
    }
  })
}
// 机床查询
export function searchmachine(num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_机床名称_查询数据',
      param: '项目流水号_check=1&项目流水号=' + num
    }
  })
}
// 分组查询
export function searchTeam(machineNumber) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_组件名称_查询数据',
      param: '机床流水号=' + machineNumber
    }
  })
}
// 初始化物料
export function searchPart(...params) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_离线外购件_出库查询',
      param: `物料名称_check=${params[0]}&物料名称=${params[1]}&物料规格_check=${params[2]}&物料规格=${params[3]}&物料型号_check=${params[4]}&物料型号=${params[5]}`,
      Pagination: params[6] + '&' + params[7]
    }
  })
}
// 人员查询 需要在部门确定之后修改
export function searchPeople(data1) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_人员查询_库存部门',
      param: '角色编号=' + data1
    }
  })
}
// 离线件出库
export function outlinePartOut(data2, data3, data4, data5, data6, data7, data8, data9, data10) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_离线采购件_零件出库',
      param: '领用者=' + data2 + '&出库数量=' + data3 + '&货位流水号=' + data4 + '&备注=' + data5 + '&项目流水号=' + data6 + '&机床流水号=' + data7 + '&组件流水号=' + data8 + '&物料流水号=' + data9 + '&出库人员流水号=' + data10
    }
  })
}
// 查询出库记录
export function outRecord(...params) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_离线外购件出库_出库记录',
      param: '物料流水号=' + params[0],
      Pagination: params[1] + '&' + params[2]
    }
  })
}
